@@ -20,11 +20,24 @@
 (define (/version args)
   "display version info"
   (display (string-append "freehoo (Freehoo) " (fh-version) "\n"
-			  "Copyright (C) 2003, 2004 Freehoo Core Team.\n"
+			  "Copyright (C) 2003, 04, 05, 06  Freehoo Core Team.\n"
 			  "This is free software; see the source for copying conditions.  There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n")))
 
 (fh-register-command! '("/version" "/version\n\t- display freehoo version information"))
 
+;; range with proper tail recursion --ab
+(define (range start end)
+  "return a list of numbers in the given range"
+  (letrec
+      ((local-range
+        (lambda (start end range-list)
+          (cond
+           ((= start end) (append range-list (list end)))
+           ((< start end) (local-range (+ start 1) end (append range-list (list start))))
+           (else '())))))
+    (local-range start end '())))
+    
+
 (define (any->symbol item)
   "converts a number into a symbol"
   (if (number? item)
