@@ -99,13 +99,8 @@ install_new_hooks (void)
      (run-hook hook-test "hi" "test")
    */
 
-  /* scm_create_hook creates a hook with name, which is
-     interned. This is only really useful from c, since in scheme, you
-     can (define name (make-hook n_args))
-   */
-
-  ex_message_send_hook =
-    scm_create_hook ("fh-message-send-hook", 2);
+  ex_message_send_hook =  scm_make_hook (scm_from_int (2));
+  scm_c_define ("fh-message-send-hook", ex_message_send_hook);
   /* hook: fh-message-send-hook
 
      is called from
@@ -119,8 +114,8 @@ install_new_hooks (void)
      (add-hook! fh-message-send-hook (lambda (to message) (do-something)))
    */
 
-  ex_message_receive_hook =
-    scm_create_hook ("fh-message-receive-hook", 2);
+  ex_message_receive_hook = scm_make_hook (scm_from_int (2));
+  scm_c_define ("fh-message-receive-hook", ex_message_receive_hook);
   /* hook: fh-message-receive-offline-hook
      is called from
      file: yafh-adapter.c
@@ -131,15 +126,15 @@ install_new_hooks (void)
      set the hook like this
      (add-hook! fh-message-receive-hook (lambda (from message) (do-something)))
    */
-  ex_contact_added_hook =
-    scm_create_hook ("fh-contact-added-hook", 2);
+  ex_contact_added_hook = scm_make_hook (scm_from_int (2));
+  scm_c_define ("fh-contact-added-hook", ex_contact_added_hook);
   /*
     set the hook like this
     (add-hook! fh-contact-added-hook (lambda (from message)  (do-something)))
    */
 
-  ex_message_receive_offline_hook = 
-    scm_create_hook ("fh-message-receive-offline-hook", 3);
+  ex_message_receive_offline_hook = scm_make_hook (scm_from_int (3));
+  scm_c_define ("fh-message-receive-offline-hook", ex_message_receive_offline_hook);
   /* hook: fh-message-receive-offline-hook
 
      is called from
@@ -152,22 +147,11 @@ install_new_hooks (void)
      (add-hook! fh-message-send-hook (lambda (from message time) (do-something)))
    */
 
-  ex_login_post_hook = scm_create_hook ("fh-login-post-hook", 0);
+  ex_login_post_hook = scm_make_hook (scm_from_int (0));
+  scm_c_define ("fh-login-post-hook", ex_login_post_hook);
   /* hook: fh-login-post-hook
      is called from
      file: messenger.c
-     function: ext_yahoo_mail_notify (...)
-     with arguments
-     "mail-from" and "mail-subject"
-
-     set the hook like this
-     (add-hook! fh-mail-notify-hook (lambda (from subject) (do-something)))
-   */
-
-  ex_mail_notify_hook = scm_create_hook ("fh-mail-notify-hook", 2);
-  /* hook: fh-mail-notify-hook
-     is called from
-     file: yahoo_backend.c
      function: send_message (...)
      with arguments
      "message-from" and "message-data"
@@ -175,6 +159,19 @@ install_new_hooks (void)
      set the hook like this
      (add-hook! fh-login-post-hook (lambda () (do-something)))
    */
+
+  ex_mail_notify_hook = scm_make_hook (scm_from_int (2));
+  scm_c_define ("fh-mail-notify-hook", ex_mail_notify_hook);
+  /* hook: fh-mail-notify-hook
+     is called from
+     file: yahoo_backend.c
+     function: ext_yahoo_mail_notify (...)
+     with arguments
+     "mail-from" and "mail-subject"
+
+     set the hook like this
+     (add-hook! fh-mail-notify-hook (lambda (from subject) (do-something)))
+   */
 }
 
 void
