@@ -17,7 +17,7 @@
 
 
 #include <stdio.h>
-#include <guile/gh.h>
+#include <libguile.h>
 #include "guile-wrapper.h"
 
 SCM __gh_standard_handler(void *data, SCM tag, SCM throw_args)
@@ -28,14 +28,14 @@ SCM __gh_standard_handler(void *data, SCM tag, SCM throw_args)
   printf ("\n(C exception handler dump)");
   printf ("\ntag        : ");
   fflush (stdout);
-  gh_display (tag);
+  scm_display (tag, scm_current_output_port ());
   printf ("\nthrow args : ");
   fflush (stdout);
-  gh_display (throw_args);
+  scm_display (throw_args, scm_current_output_port ());
   printf ("\ndata       : [%s]\n", (char *) data);
   fflush (stdout);
   scm_backtrace ();
   fflush (stdout);
-  gh_newline();
+  scm_newline (scm_current_output_port ());
   return SCM_UNSPECIFIED;
 }
