@@ -538,16 +538,20 @@ interpreter (char *line)
   history_line = strdup (line);
   command = get_token (&line);
 
+  /* Avati - The below check is commented on purpose
+     because it breaks the logic of setting the default buddy
+     by just typing the buddyname as a command.
+     paranoia should encourage you to strcmp the 'command' string
+     over the buddy loop and then returning if your not happy
+   */
+
   /* This is not a command. Ignore all empty messages */
-  if (command[0] != '?' && command[0] != '/' &&
-      (!line || (line && *line) == 0))
+  if (! (command[0] != '?' && command[0] != '/' &&
+	(!line || (line && *line) == 0)))
     {
-      free (history_line);
-      return;
+       add_history (history_line);
     }
-  
-  add_history (history_line);
-  free (history_line);
+    free (history_line);
     
   /*  if (line)
       line = stripwhite (line);
