@@ -20,7 +20,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <readline/readline.h>
-#include <guile/gh.h>
+#include <libguile.h>
 #include <assert.h>
 #include <glib.h>
 #include <yahoo2.h>
@@ -44,15 +44,7 @@ ex_set_some_thing_x (SCM scm_some_thing)
 {
   int some_thing_length;
   
-  // FIXME: currently I'm not validating the result of gh_scm2newstr
-  // also note that Scheme strings may contain arbitrary data,
-  // including null characters.  This means that null termination is
-  // not a reliable way to determine the length of the returned value.
-  // However, the function always copies the complete contents of
-  // scm_some_thing, and sets *some_thing_length to the true length of the
-  // string (when some_thing_length is non-null)
-  
-  set_some_thing (gh_scm2newstr (scm_some_thing, &some_thing_length));
+  set_some_thing (scm_to_locale_string (scm_some_thing, &some_thing_length));
   
   return SCM_UNSPECIFIED;
 }
@@ -62,7 +54,7 @@ ex_set_some_thing_x (SCM scm_some_thing)
 SCM
 ex_version (void)
 {
-  return (gh_str02scm (VERSION));
+  return (scm_from_locale_string (VERSION));
 }
 
 /* this function should be used to print messages at run- time from the
@@ -72,7 +64,7 @@ SCM
 ex_display (SCM scm_message)
 {
   char *str;
-  PRINTF_MESSAGE ("%s\n", (str = gh_scm2newstr (scm_message, NULL)));
+  PRINTF_MESSAGE ("%s\n", (str = scm_to_locale_string (scm_message)));
   free(str);
   return SCM_UNSPECIFIED;
 }
@@ -80,7 +72,7 @@ ex_display (SCM scm_message)
 SCM
 ex_toggle_x (SCM scm_what2toggle)
 {
-  char * str = gh_scm2newstr(scm_what2toggle, NULL);
+  char * str = scm_to_locale_string(scm_what2toggle);
   if (strcasecmp (str, 
 		  "bell") == 0)
     toggle_bell ();
@@ -94,7 +86,6 @@ ex_toggle_x (SCM scm_what2toggle)
 		       "status") == 0)
     toggle_status ();
   else
-    // FIXME: I think this is now working!!  --ab
     scm_wrong_type_arg (str,
 			0, SCM_UNSPECIFIED);
   free(str);
@@ -129,26 +120,26 @@ SCM
 ex_set_default_status_x (SCM scm_status)
 {
   if (get_current_status () == -1)
-    set_current_status (gh_scm2long (scm_status));
+    set_current_status (scm_to_long (scm_status));
   return SCM_UNSPECIFIED;
 }
 
 SCM
 ex_get_global_extensions_directory (void)
 {
-  return (gh_str02scm (get_global_extensions_directory ()));
+  return (scm_from_locale_string (get_global_extensions_directory ()));
 }
 
 SCM
 ex_get_local_extensions_directory (void)
 {
-  return (gh_str02scm (get_local_extensions_directory ()));
+  return (scm_from_locale_string (get_local_extensions_directory ()));
 }
 
 SCM
 ex_load (SCM scm_filename)
 {
-  char *filename = gh_scm2newstr (scm_filename, NULL);
+  char *filename = scm_to_locale_string (scm_filename);
   fh_load (filename);
   free(filename);
   return SCM_UNSPECIFIED;
@@ -157,31 +148,31 @@ ex_load (SCM scm_filename)
 SCM
 ex_get_home_dir (void)
 {
-  return (gh_str02scm (get_home_directory ()));
+  return (scm_from_locale_string (get_home_directory ()));
 }
 
 SCM
 ex_get_config_dir (void)
 {
-  return (gh_str02scm (get_config_directory ()));
+  return (scm_from_locale_string (get_config_directory ()));
 }
 
 SCM
 ex_get_config_filename (void)
 {
-  return (gh_str02scm (get_config_filename ()));
+  return (scm_from_locale_string (get_config_filename ()));
 }
 
 SCM
 ex_get_download_filename (void)
 {
-  return (gh_str02scm (get_download_filename ()));
+  return (scm_from_locale_string (get_download_filename ()));
 }
 
 SCM
 ex_set_default_login_id_x (SCM scm_default_login_id)
 {
-  char * login = gh_scm2newstr (scm_default_login_id, NULL);
+  char * login = scm_to_locale_string (scm_default_login_id);
   set_default_login_id (login);
 //  free(login);
   return SCM_UNSPECIFIED;
@@ -190,13 +181,13 @@ ex_set_default_login_id_x (SCM scm_default_login_id)
 SCM
 ex_get_default_login_id (void)
 {
-  return gh_str02scm (get_default_login_id ());
+  return scm_from_locale_string (get_default_login_id ());
 }
 
 SCM
 ex_set_default_password_x (SCM scm_default_password)
 {
-  char *passwd = gh_scm2newstr (scm_default_password, NULL);
+  char *passwd = scm_to_locale_string (scm_default_password);
   set_default_password (passwd);
 //  free (passwd);
   return SCM_UNSPECIFIED;
@@ -213,12 +204,11 @@ ex_set_current_target_buddy_x (SCM scm_current_target_buddy, SCM scm_current_tar
   if (scm_current_target_buddy != SCM_BOOL_F)
     {
       current_target_buddy = 
-	gh_scm2newstr (scm_current_target_buddy, NULL);
+	scm_to_locale_string (scm_current_target_buddy);
     }
   if (scm_current_target_buddy_mode != SCM_BOOL_F)
     {
-       if(!strcasecmp ( (mode_str = gh_scm2newstr (scm_current_target_buddy_mode,NULL)),
-			       "receive"))
+       if(!strcasecmp ( (mode_str = scm_to_locale_string (scm_current_target_buddy_mode)), "receive"))
           {
              mode = current_target_buddy_mode_receive;
           }
@@ -235,8 +225,8 @@ ex_send_message (SCM scm_to, SCM scm_message)
 {
   char *to, *msg;
 
-  to = gh_scm2newstr (scm_to, NULL);
-  msg = gh_scm2newstr (scm_message, NULL);
+  to = scm_to_locale_string (scm_to);
+  msg = scm_to_locale_string (scm_message);
   send_message (to,
 		msg);
   return SCM_UNSPECIFIED;
@@ -247,8 +237,8 @@ ex_send_message_no_hook (SCM scm_to, SCM scm_message)
 {
   char *to, *msg;
 
-  to = gh_scm2newstr (scm_to, NULL);
-  msg = gh_scm2newstr (scm_message, NULL);
+  to = scm_to_locale_string (scm_to);
+  msg = scm_to_locale_string (scm_message);
   send_message_no_hook (to,
 			msg);
   return SCM_UNSPECIFIED;
@@ -272,7 +262,7 @@ SCM
 ex_set_prompt_x (SCM scm_prompt)
 {
   char *prompt;
-  set_default_prompt ((prompt = gh_scm2newstr (scm_prompt, NULL)));
+  set_default_prompt ((prompt = scm_to_locale_string (scm_prompt)));
 //  free (prompt);
   return SCM_UNSPECIFIED;
 }
@@ -291,19 +281,17 @@ ex_get_buddy_list ()
       if (!temp_buddy)
 	break;
 	  
-      if (gh_list_p (scm_buddy_list) != 1)
+      if (scm_is_true (scm_list_p (scm_buddy_list)) != 1)
 	{
 	  scm_buddy_list = 
-	    gh_list (gh_str02scm (temp_buddy->yahoo_id), 
+	    scm_list_n (scm_from_locale_string (temp_buddy->yahoo_id), 
 		     SCM_UNDEFINED);
 	}
       else
 	{
 	  scm_buddy_list = 
-	    gh_append2 (scm_buddy_list,
-			gh_list (gh_str02scm 
-				 (temp_buddy->yahoo_id),
-				 SCM_UNDEFINED));
+	    scm_append (scm_list_n (scm_buddy_list,
+				    scm_list_n (scm_from_locale_string (temp_buddy->yahoo_id), SCM_UNDEFINED), SCM_UNDEFINED));
 	}
       i++;
     }
@@ -314,8 +302,8 @@ ex_get_buddy_list ()
 SCM
 ex_add_buddy (SCM scm_buddy, SCM scm_group)
 {
-  char *buddy =  (gh_scm2newstr (scm_buddy, NULL));
-  char *group =  (gh_scm2newstr (scm_group, NULL));
+  char *buddy =  (scm_to_locale_string (scm_buddy));
+  char *group =  (scm_to_locale_string (scm_group));
   
   /*
     FIXME: Visu, Aug 23, 2004:
@@ -351,7 +339,7 @@ ex_fh_logoff ()
 SCM
 ex_fh_dict_add_word (SCM word)
 {
-    char *w = gh_scm2newstr (word, NULL);
+    char *w = scm_to_locale_string (word);
     struct dict_words *dw = word_list;
     struct dict_words *newnode = calloc (1, sizeof (word_list));
 
@@ -392,7 +380,7 @@ ex_fh_dict_add_word (SCM word)
 SCM
 ex_fh_dict_add_word_sorted (SCM word)
 {
-    char *w = gh_scm2newstr (word, NULL);
+    char *w = scm_to_locale_string (word);
     struct dict_words *newnode = calloc (1, sizeof (word_list));
 
     newnode->word = w;
@@ -406,7 +394,7 @@ ex_fh_dict_add_word_sorted (SCM word)
 SCM
 ex_fh_dict_del_word (SCM word)
 {
-  char *w = gh_scm2newstr (word, NULL);
+  char *w = scm_to_locale_string (word);
   struct dict_words * dw = word_list;
   struct dict_words *delnode =NULL;
 
