@@ -66,7 +66,7 @@
 #include "yahoo-utils.h"
 #include "extension.h"
 
-static char *local_host = NULL;
+// static char *local_host = "127.0.0.1";
 static int do_mail_notify = 1;
 static int do_yahoo_debug = 0;
 static int ignore_system = 0;
@@ -149,9 +149,9 @@ rearm (time_t * timer, int seconds)
   *timer += seconds;
 }
 
-/* FIXME: Fixed seg-fault while empty routing table. Some one needs to
-   submit this as a patch to the libyahoo2 sample-client.c source 
-   -- Anand Babu */
+#if 0
+/* This code is buggy and non-portable. Output of "netstat" and
+"ifconfig" has changed resulting in memory corruption. */
 static char *
 get_local_addresses ()
 {
@@ -231,6 +231,7 @@ IP_TEST_2:
 
   return addresses;
 }
+#endif
 
 static double
 get_time ()
@@ -937,7 +938,7 @@ ext_yahoo_login (yahoo_local_account * ylad, int login_mode)
   LOG (("ext_yahoo_login"));
 
   ylad->id = yahoo_init_with_attributes (ylad->yahoo_id, ylad->password,
-					 "local_host", local_host,
+					 "local_host", "127.0.0.1",
 					 "pager_port", 23, NULL);
   ylad->status = YAHOO_STATUS_OFFLINE;
   yahoo_login (ylad->id, login_mode);
@@ -1612,7 +1613,9 @@ messenger_main (int argc, char *argv[])
   char *password = get_default_password ();
 
   ylad = y_new0 (yahoo_local_account, 1);
-  local_host = strdup (get_local_addresses ());
+
+  // FIXME: get_local_address () is BUGGY.
+  //  local_host = strdup (get_local_addresses ());
 
   if (!login_id)
     {
