@@ -95,7 +95,13 @@ struct _conn
   int remove;
 };
 
-typedef struct { char *who,*fname,*url,*msg; unsigned long fsize;} get_file_geturl_data_t;
+struct get_file_geturl_data
+{ 
+  char *who, *fname, *url, *msg;
+  unsigned long fsize;
+};
+typedef struct get_file_geturl_data get_file_geturl_data_t;
+
 void get_file_geturl_callback(int id, int fd, int error, const char * filename, unsigned long size, void *data);
 
 void ext_yahoo_got_im (int id, char *who, char *msg, long tm,
